(***************************************************************************************************************)
(******                       FeynRules mod-file for Model Independent searches of top partners		  ******)
(******                                      B(-1/3) singlet	   	       		                  ******)
(******                                                                                                   ******)
(******     Authors: M. Buchkremer, G. Cacciapaglia, A. Deandrea,L. Panizzi	 			  ******)
(******                                                                                                   ******)
(***************************************************************************************************************)

M$ModelName = "BsingletVL";


M$Information = {Authors -> {"M. Buchkremer","G. Cacciapaglia","A. Deandrea","L. Panizzi"}, 
             Version -> "1.2.5",
             Date -> "15. 04. 2014",
             Institutions -> {"Universite catholique de Louvain (CP3)","Universite de Lyon (CNRS/IN2P3)","University of Southampton (School of Physics and Astronomy)"},
             Emails -> {"mathieu.buchkremer@uclouvain.be", "g.cacciapaglia@ipnl.in2p3.fr","deandrea@ipnl.in2p3.fr", "l.panizzi@soton.ac.uk"},
 	     References -> {"arXiv:1305.4172"}};


(******* Index definitions ********)

IndexRange[ Index[Generation] ] = Range[3]
IndexRange[ Index[Colour] ] = NoUnfold[Range[3]]
IndexRange[ Index[Gluon] ] = NoUnfold[Range[8]]
IndexRange[ Index[SU2W] ] = Unfold[Range[3]]
IndexStyle[Colour, i]
IndexStyle[Generation, f]
IndexStyle[Gluon ,a]
IndexStyle[SU2W ,k]

(******* Gauge parameters (for FeynArts) ********)

GaugeXi[ V[1] ] = GaugeXi[A];
GaugeXi[ V[2] ] = GaugeXi[Z];
GaugeXi[ V[3] ] = GaugeXi[W];
GaugeXi[ V[4] ] = GaugeXi[G];
GaugeXi[ S[1] ] = 1;
GaugeXi[ S[2] ] = GaugeXi[Z];
GaugeXi[ S[3] ] = GaugeXi[W];
GaugeXi[ U[1] ] = GaugeXi[A];
GaugeXi[ U[2] ] = GaugeXi[Z];
GaugeXi[ U[31] ] = GaugeXi[W];
GaugeXi[ U[32] ] = GaugeXi[W];
GaugeXi[ U[4] ] = GaugeXi[G];

(****************  Parameters *************)

M$Parameters = {

  (* External parameters, SM *)

  \[Alpha]EWM1== {
        ParameterType -> External,
        BlockName -> SMINPUTS,
        ParameterName -> aEWM1,
        InteractionOrder -> {QED, -2},
        Value -> 127.9,
        Description -> "Inverse of the electroweak coupling constant"},

  Gf == {
        ParameterType -> External,
        BlockName -> SMINPUTS,
        TeX -> Subscript[G, f],
        InteractionOrder -> {QED, 2},
        Value -> 1.16600 * 10^(-5),
        Description -> "Fermi constant"},

  \[Alpha]S == {
        ParameterType -> External,
        BlockName -> SMINPUTS,
        TeX -> Subscript[\[Alpha], s],
        ParameterName -> aS,
        InteractionOrder -> {QCD, 2},
        Value -> 0.118,
        Description -> "Strong coupling constant at the Z pole."},

  ymdo == {
        ParameterType -> External,
        BlockName -> YUKAWA,
        Value -> 5.04*10^(-3),
	OrderBlock -> {1},
	Description -> "Down Yukawa mass"},

  ymup == {
        ParameterType -> External,
        BlockName -> YUKAWA,
        Value -> 2.55*10^(-3),
        OrderBlock -> {2},
        Description -> "Up Yukawa mass"},

  yms == {
        ParameterType -> External,
        BlockName -> YUKAWA,
        Value -> 0.101,
	OrderBlock -> {3},
	Description -> "Strange Yukawa mass"},

  ymc == {
        ParameterType -> External,
        BlockName -> YUKAWA,
        Value -> 1.25,
        OrderBlock -> {4},
        Description -> "Charm Yukawa mass"},

  ymb == {
        ParameterType -> External,
        BlockName -> YUKAWA,
        Value -> 4.2,
        OrderBlock -> {5},
        Description -> "Bottom Yukawa mass"},

  ymt == {
        ParameterType -> External,
        BlockName -> YUKAWA,
        Value -> 174.3,
        OrderBlock -> {6},
        Description -> "Top Yukawa mass"},

  yme == {
        ParameterType -> External,
        BlockName -> YUKAWA,
        Value ->  5.11*10^(-4),
        OrderBlock -> {11},
        Description -> "Electron Yukawa mass"},

  ymm == {
        ParameterType -> External,
        BlockName -> YUKAWA,
        Value -> 0.10566,
        OrderBlock -> {13},
        Description -> "Muon Yukawa mass"},

  ymtau == {
        ParameterType -> External,
        BlockName -> YUKAWA,
        Value -> 1.777,
        OrderBlock -> {15},
        Description -> "Tau Yukawa mass"},

  CKM == {
        ParameterType -> External,
        BlockName -> CKMBlock,
        ComplexParameter -> False,
       Indices -> {Index[Generation], Index[Generation]},
       TensorClass -> CKM,
       Unitary -> True,
       Value -> {CKM[1,1] -> 0.97428,
                 CKM[1,2] -> 0.2253,
                 CKM[1,3] -> 0.00347,
                 CKM[2,1] -> 0.2252,
                 CKM[2,2] -> 0.97345,
                 CKM[2,3] -> 0.0410,
                 CKM[3,1] -> 0.00862,
                 CKM[3,2] -> 0.0403,
                 CKM[3,3] -> 0.999152},
       Description -> "SM CKM Matrix"},

  (* External parameters, VLQ *)

  Gvl == {
        TeX -> Subscript[g, VL],
        ParameterType -> External,
        BlockName -> Gvl,
        ComplexParameter -> False,
        Value ->  1,
        Description -> "VL-VL-gauge factor multiplying SM coupling"},

 gstar == {
        ParameterType -> External,
        BlockName -> Kappa,
        ComplexParameter -> False,
        Value -> 0.1,
        Description -> "gstar"},

 RL == {
        ParameterType -> External,
        BlockName -> Zeta,
        ComplexParameter -> False,
        Value -> 1,
        Description -> "RL rate into light"},

  KB == {
        ParameterType -> Internal,
        BlockName -> Kappa,
        ComplexParameter -> False,
        Value -> gstar,
        Description -> "Kappa_B parameter"},

  zetaBdL == {
        ParameterType -> Internal,
        BlockName -> Zeta,
        ComplexParameter -> False,
        Value -> RL/(1+RL),
	Description -> "B-d mixing (left-handed)"},

  zetaBsL == {
        ParameterType -> Internal,
        BlockName -> Zeta,
        ComplexParameter -> False,
        Value -> 0,
	Description -> "B-s mixing (left-handed)"},

  zetaBbL == {
        ParameterType -> Internal,
        BlockName -> Zeta,
        ComplexParameter -> False,
        Value -> 1/(1+RL),
	Description -> "B-b mixing (left-handed)"},

  zetaBdR == {
        ParameterType -> Internal,
        BlockName -> Zeta,
        ComplexParameter -> False,
        Value -> 0,
	Description -> "B-d mixing (right-handed)"},

  zetaBsR == {
        ParameterType -> Internal,
        BlockName -> Zeta,
        ComplexParameter -> False,
        Value -> 0,
	Description -> "B-s mixing (right-handed)"},

  zetaBbR == {
        ParameterType -> Internal,
        BlockName -> Zeta,
        ComplexParameter -> False,
        Value -> 0,
	Description -> "B-b mixing (right-handed)"},


   (* Internal Parameters, SM *)

  \[Alpha]EW == {
        ParameterType -> Internal,
        Value -> 1/\[Alpha]EWM1,
        TeX -> Subscript[\[Alpha], EW],
        ParameterName -> aEW,
        InteractionOrder -> {QED, 2},
        Description -> "Electroweak coupling constant"},


  MW == {
        ParameterType -> Internal,
        Value -> Sqrt[MZ^2/2+Sqrt[MZ^4/4-Pi/Sqrt[2]*\[Alpha]EW/Gf*MZ^2]],
        TeX  -> Subscript[M, W],
        Description -> "W mass"},

  sw2 == {
        ParameterType -> Internal,
        Value -> 1-(MW/MZ)^2,
        Description -> "Squared Sin of the Weinberg angle"},

   ee == {
        TeX -> e,
        ParameterType -> Internal,
        Value -> Sqrt[4 Pi \[Alpha]EW],
        InteractionOrder -> {QED, 1},
        Description -> "Electric coupling constant"},

   cw == {
        TeX -> Subscript[c, w],
        ParameterType -> Internal,
        Value -> Sqrt[1 - sw2],
        Description -> "Cos of the Weinberg angle"},  

   sw == {
        TeX -> Subscript[s, w],
        ParameterType -> Internal,
        Value -> Sqrt[sw2],
        Description -> "Sin of the Weinberg angle"},  

   gw == {
        TeX -> Subscript[g, w],
        ParameterType -> Internal,
        Value -> ee / sw,
        InteractionOrder -> {QED, 1},
        Description -> "Weak coupling constant"},

   g1 == {
        TeX -> Subscript[g, 1],
        ParameterType -> Internal,
        Value -> ee / cw,
        InteractionOrder -> {QED, 1},
        Description -> "U(1)Y coupling constant"},

   gs == {
        TeX -> Subscript[g, s],
        ParameterType -> Internal,
        Value -> Sqrt[4 Pi \[Alpha]S],
        InteractionOrder -> {QCD, 1},
        ParameterName -> G,
        Description -> "Strong coupling constant"},

   v == {
        ParameterType -> Internal,
        Value -> 2*MW*sw/ee,
        InteractionOrder -> {QED, -1},
        Description -> "Higgs VEV"},

   \[Lambda] == {
        ParameterType -> Internal,
        Value -> MH^2/(2*v^2),
        InteractionOrder -> {QED, 2},
        ParameterName -> lam,
        Description -> "Higgs quartic coupling"},

   muH == {
        ParameterType -> Internal,
        Value -> Sqrt[v^2 \[Lambda]],
        TeX -> \[Mu],
        Description -> "Coefficient of the quadratic piece of the Higgs potential"},

   yl == {
        TeX -> Superscript[y, l],
        Indices -> {Index[Generation]},
        AllowSummation -> True,
        ParameterType -> Internal,
        Value -> {yl[1] -> Sqrt[2] yme / v, yl[2] -> Sqrt[2] ymm / v, yl[3] -> Sqrt[2] ymtau / v},
        ParameterName -> {yl[1] -> ye, yl[2] -> ym, yl[3] -> ytau},
        InteractionOrder -> {QED, 1},
        ComplexParameter -> False,
        Description -> "Lepton Yukawa coupling"},

   yu == {
        TeX -> Superscript[y, u],
        Indices -> {Index[Generation]},
        AllowSummation -> True,
        ParameterType -> Internal,
        Value -> {yu[1] -> Sqrt[2] ymup / v, yu[2] -> Sqrt[2] ymc / v, yu[3] -> Sqrt[2] ymt / v},
        ParameterName -> {yu[1] -> yup, yu[2] -> yc, yu[3] -> yt},
        InteractionOrder -> {QED, 1},
        ComplexParameter -> False,
        Description -> "U-quark Yukawa coupling"},

   yd == {
        TeX -> Superscript[y, d],
        Indices -> {Index[Generation]},
        AllowSummation -> True,
        ParameterType -> Internal,
        Value -> {yd[1] -> Sqrt[2] ymdo / v, yd[2] -> Sqrt[2] yms / v, yd[3] -> Sqrt[2] ymb / v},
        ParameterName -> {yd[1] -> ydo, yd[2] -> ys, yd[3] -> yb},
        InteractionOrder -> {QED, 1},
        ComplexParameter -> False,
        Description -> "D-quark Yukawa coupling"},


   (************** Internal Parameters, VLQ **************)


   (* B couplings *)

  KBdLw == {
        ParameterType -> Internal,
        BlockName -> Kappa,
        ComplexParameter -> False,
        Value -> (ee/sw*Sqrt[zetaBdL])/Sqrt[2],
        InteractionOrder -> {QED, 1},
        Description -> "BdW coupling (left-handed)"},

  KBsLw == {
        ParameterType -> Internal,
        BlockName -> Kappa,
        ComplexParameter -> False,
        Value -> (ee/sw*Sqrt[zetaBsL])/Sqrt[2],
        InteractionOrder -> {QED, 1},
        Description -> "BsW coupling (left-handed)"},

  KBbLw == {
        ParameterType -> Internal,
        BlockName -> Kappa,
        ComplexParameter -> False,
        Value -> (gw*Sqrt[zetaBbL])/Sqrt[2],
        InteractionOrder -> {QED, 1},
        Description -> "BbW coupling (left-handed)"},

  KBdRw == {
        ParameterType -> Internal,
        BlockName -> Kappa,
        ComplexParameter -> False,
        Value -> (ee/sw*Sqrt[zetaBdR])/Sqrt[2],
        InteractionOrder -> {QED, 1},
        Description -> "BdW coupling (right-handed)"},

  KBsRw == {
        ParameterType -> Internal,
        BlockName -> Kappa,
        ComplexParameter -> False,
        Value -> (gw*Sqrt[zetaBsR])/Sqrt[2],
        InteractionOrder -> {QED, 1},
        Description -> "BsW coupling (right-handed)"},

  KBbRw == {
        ParameterType -> Internal,
        BlockName -> Kappa,
        ComplexParameter -> False,
        Value -> (gw*Sqrt[zetaBbR])/Sqrt[2],
        InteractionOrder -> {QED, 1},
        Description -> "BbW coupling (right-handed)"},

  KBdLz == {
        ParameterType -> Internal,
        BlockName -> Kappa,
        ComplexParameter -> False,
        Value -> (gw*Sqrt[zetaBdL])/2/cw,
        InteractionOrder -> {QED, 1},
        Description -> "BdZ coupling (left-handed)"},

  KBsLz == {
        ParameterType -> Internal,
        BlockName -> Kappa,
        ComplexParameter -> False,
        Value -> (gw*Sqrt[zetaBsL])/2/cw,
        InteractionOrder -> {QED, 1},
        Description -> "BsZ coupling (left-handed)"},

  KBbLz == {
        ParameterType -> Internal,
        BlockName -> Kappa,
        ComplexParameter -> False,
        Value -> (gw*Sqrt[zetaBbL])/2/cw,
        InteractionOrder -> {QED, 1},
        Description -> "BbZ coupling (left-handed)"},

  KBdRz == {
        ParameterType -> Internal,
        BlockName -> Kappa,
        ComplexParameter -> False,
        Value -> (gw*Sqrt[zetaBdR])/2/cw,
        InteractionOrder -> {QED, 1},
        Description -> "BdZ coupling (right-handed)"},

  KBsRz == {
        ParameterType -> Internal,
        BlockName -> Kappa,
        ComplexParameter -> False,
        Value -> (gw*Sqrt[zetaBsR])/2/cw,
        InteractionOrder -> {QED, 1},
        Description -> "BsZ coupling (right-handed)"},

  KBbRz == {
        ParameterType -> Internal,
        BlockName -> Kappa,
        ComplexParameter -> False,
        Value -> (gw*Sqrt[zetaBbR])/2/cw,
        InteractionOrder -> {QED, 1},
        Description -> "BbZ coupling (right-handed)"},

  KBdLh == {
        ParameterType -> Internal,
        BlockName -> Kappa,
        ComplexParameter -> False,
        Value -> (Sqrt[zetaBdL]),
        InteractionOrder -> {QED, 0},
        Description -> "BdH coupling (left-handed)"},

  KBsLh == {
        ParameterType -> Internal,
        BlockName -> Kappa,
        ComplexParameter -> False,
        Value -> (Sqrt[zetaBsL]),
        InteractionOrder -> {QED, 0},
        Description -> "BsH coupling (left-handed)"},

  KBbLh == {
        ParameterType -> Internal,
        BlockName -> Kappa,
        ComplexParameter -> False,
        Value -> (Sqrt[zetaBbL]),
        InteractionOrder -> {QED, 0},
        Description -> "BbH coupling (left-handed)"},

  KBdRh == {
        ParameterType -> Internal,
        BlockName -> Kappa,
        ComplexParameter -> False,
        Value -> (Sqrt[zetaBdR]),
        InteractionOrder -> {QED, 0},
        Description -> "BdH coupling (right-handed)"},

  KBsRh == {
        ParameterType -> Internal,
        BlockName -> Kappa,
        ComplexParameter -> False,
        Value -> (Sqrt[zetaBsR]),
        InteractionOrder -> {QED, 0},
        Description -> "BsH coupling (right-handed)"},

  KBbRh == {
        ParameterType -> Internal,
        BlockName -> Kappa,
        ComplexParameter -> False,
        Value -> (Sqrt[zetaBbR]),
        InteractionOrder -> {QED, 0},
        Description -> "BbH coupling (right-handed)"}

}

 
(************** Gauge Groups ******************)

M$GaugeGroups = {

  U1Y == {
        Abelian -> True,
        GaugeBoson -> B,
        Charge -> Y,
        CouplingConstant -> g1},

  SU2L == {
        Abelian -> False,
        GaugeBoson -> Wi,
        StructureConstant -> Eps,
        CouplingConstant -> gw},

  SU3C == {
        Abelian -> False,
        GaugeBoson -> G,
        StructureConstant -> f,
        SymmetricTensor -> dSUN,
        Representations -> {T, Colour},
        CouplingConstant -> gs}
}

(********* Particle Classes **********)

M$ClassesDescription = {

(********** Fermions ************)
	(* Leptons (neutrino): I_3 = +1/2, Q = 0 *)
  F[1] == {
        ClassName -> vl,
        ClassMembers -> {ve,vm,vt},
        FlavorIndex -> Generation,
	SelfConjugate -> False,
	Indices -> {Index[Generation]},
        Mass -> 0,
        Width -> 0,
	QuantumNumbers -> {LeptonNumber -> 1},
	PropagatorLabel -> {"v", "ve", "vm", "vt"} ,
	PropagatorType -> S,
	PropagatorArrow -> Forward,
        PDG -> {12,14,16},
        FullName -> {"Electron-neutrino", "Mu-neutrino", "Tau-neutrino"} },

	(* Leptons (electron): I_3 = -1/2, Q = -1 *)
  F[2] == {
        ClassName -> l,
        ClassMembers -> {e, m, tt},
        FlavorIndex -> Generation,
	SelfConjugate -> False,
	Indices -> {Index[Generation]},
	Mass -> {Ml, {Me, 5.11 * 10^(-4)}, {MM, 0.10566}, {MTA, 1.777}},
        Width -> 0,
	QuantumNumbers -> {Q -> -1, LeptonNumber -> 1},
	PropagatorLabel -> {"l", "e", "m", "tt"},
	PropagatorType -> Straight,
        ParticleName -> {"e-", "m-", "tt-"},
        AntiParticleName -> {"e+", "m+", "tt+"},
	PropagatorArrow -> Forward,
        PDG -> {11, 13, 15},
        FullName -> {"Electron", "Muon", "Tau"} },

	(* Quarks (u): I_3 = +1/2, Q = +2/3 *)
  F[3] == {
        ClassMembers -> {u, c, t},
        ClassName -> uq,
        FlavorIndex -> Generation,
	SelfConjugate -> False,
	Indices -> {Index[Generation], Index[Colour]},
	Mass -> {Mu, {MU, 2.55*10^(-3)}, {MC, 1.40}, {MT, 174.3}},
        Width -> {0, 0, {WT, 1.51013490}},
	QuantumNumbers -> {Q -> 2/3},
	PropagatorLabel -> {"uq", "u", "c", "t"},
	PropagatorType -> Straight,
	PropagatorArrow -> Forward,
        PDG -> {2, 4, 6}, 
        FullName -> {"u-quark", "c-quark", "t-quark"}},

	(* Quarks (d): I_3 = -1/2, Q = -1/3 *) 
  F[4] == {
        ClassMembers -> {d, s, b},
        ClassName -> dq,
        FlavorIndex -> Generation,
	SelfConjugate -> False,
	Indices -> {Index[Generation], Index[Colour]},
	Mass -> {Md, {MD,  5.04*10^(-3)}, {MS, 0.101}, {MB, 4.2}},
        Width -> 0,
	QuantumNumbers -> {Q -> -1/3},
	PropagatorLabel -> {"dq", "d", "s", "b"},
	PropagatorType -> Straight, 
	PropagatorArrow -> Forward,
        PDG -> {1,3,5},
        FullName -> {"d-quark", "s-quark", "b-quark"} },


	(* VLQ Quarks B, Q=-1/3 *)
  F[7] == {
        ClassName -> bpq,
        ClassMembers -> {bp},
	SelfConjugate -> False,
	Indices -> {Index[Colour]},
	Mass -> {{MQ,1000}},
        Width -> {{WBP, 1}},
	QuantumNumbers -> {Q -> -1/3},
	PropagatorLabel -> {"bp"},
	PropagatorType -> Straight,
	PropagatorArrow -> Forward,
        PDG -> {6000007},
        FullName -> {"B-quark"}},


(********** Ghosts **********)
	U[1] == {
       ClassName -> ghA,
       SelfConjugate -> False,
       Indices -> {},
       Ghost -> A,
       Mass -> 0,
       QuantumNumbers -> {GhostNumber -> 1},
       PropagatorLabel -> uA,
       PropagatorType -> GhostDash,
       PropagatorArrow -> Forward},

	U[2] == {
       ClassName -> ghZ,
       SelfConjugate -> False,
       Indices -> {},
       Mass -> {MZ, 91.1876},
       Ghost -> Z,
       QuantumNumbers -> {GhostNumber -> 1},
       PropagatorLabel -> uZ,
       PropagatorType -> GhostDash,
       PropagatorArrow -> Forward},

	U[31] == {
       ClassName -> ghWp,
       SelfConjugate -> False,
       Indices -> {},
       Mass -> {MW, Internal},
       Ghost -> W,
       QuantumNumbers -> {Q-> 1, GhostNumber -> 1},
       PropagatorLabel -> uWp,
       PropagatorType -> GhostDash,
       PropagatorArrow -> Forward},

   U[32] == {
       ClassName -> ghWm,
       SelfConjugate -> False,
       Indices -> {},
       Mass -> {MW, Internal},
       Ghost -> Wbar,
       QuantumNumbers -> {Q-> -1, GhostNumber -> 1},
       PropagatorLabel -> uWm,
       PropagatorType -> GhostDash,
       PropagatorArrow -> Forward},

 	U[4] == {
       ClassName -> ghG,
       SelfConjugate -> False,
       Indices -> {Index[Gluon]},
       Ghost -> G,
       Mass -> 0,
       QuantumNumbers -> {GhostNumber -> 1},
       PropagatorLabel -> uG,
       PropagatorType -> GhostDash,
       PropagatorArrow -> Forward},

	U[5] == {
        ClassName -> ghWi,
        Unphysical -> True,
        Definitions -> {ghWi[1] -> (ghWp + ghWm)/Sqrt[2],
                        ghWi[2] -> (ghWm - ghWp)/Sqrt[2]/I,
                        ghWi[3] -> cw ghZ + sw ghA},
        SelfConjugate -> False,
        Ghost -> Wi,
        Indices -> {Index[SU2W]},
        FlavorIndex -> SU2W},

	U[6] == {
        ClassName -> ghB,
	SelfConjugate -> False,
        Definitions -> {ghB -> -sw ghZ + cw ghA},
	Indices -> {},
        Ghost -> B,
        Unphysical -> True},

(************ Gauge Bosons ***************)
	(* Gauge bosons: Q = 0 *)
  V[1] == {
        ClassName -> A,
	SelfConjugate -> True,
	Indices -> {},
	Mass -> 0,
        Width -> 0,
	PropagatorLabel -> "a",
	PropagatorType -> W,
	PropagatorArrow -> None,
        PDG -> 22,
        FullName -> "Photon" },

  V[2] == {
        ClassName -> Z,
	SelfConjugate -> True, 
	Indices -> {},
	Mass -> {MZ, 91.1876},
        Width -> {WZ, 2.44639985},
	PropagatorLabel -> "Z",
	PropagatorType -> Sine,
	PropagatorArrow -> None,
        PDG -> 23,
        FullName -> "Z" },

	(* Gauge bosons: Q = -1 *)
  V[3] == {
        ClassName -> W,
	SelfConjugate -> False,
	Indices -> {},
	Mass -> {MW, Internal},
        Width -> {WW, 2.03535570},
	QuantumNumbers -> {Q -> 1},
	PropagatorLabel -> "W",
	PropagatorType -> Sine,
	PropagatorArrow -> Forward,
	ParticleName ->"W+",
	AntiParticleName ->"W-",
        PDG -> 24,
        FullName -> "W" },

V[4] == {
        ClassName -> G,
	SelfConjugate -> True,
	Indices -> {Index[Gluon]},
	Mass -> 0,
        Width -> 0,
        PropagatorLabel -> G,
	PropagatorType -> C,
	PropagatorArrow -> None,
        PDG -> 21,
        FullName -> "G" },

V[5] == {
        ClassName -> Wi,
        Unphysical -> True,
        Definitions -> {Wi[mu_, 1] -> (W[mu] + Wbar[mu])/Sqrt[2],
                        Wi[mu_, 2] -> (Wbar[mu] - W[mu])/Sqrt[2]/I,
                        Wi[mu_, 3] -> cw Z[mu] + sw A[mu]},
        SelfConjugate -> True,
        Indices -> {Index[SU2W]},
        FlavorIndex -> SU2W,
        Mass -> 0,
        PDG -> {1,2,3}},

V[6] == {
        ClassName -> B,
	SelfConjugate -> True,
        Definitions -> {B[mu_] -> -sw Z[mu] + cw A[mu]},
	Indices -> {},
	Mass -> 0,
        Unphysical -> True},


(************ Scalar Fields **********)
	(* physical Higgs: Q = 0 *) 
  S[1] == {
        ClassName -> H,
	SelfConjugate -> True,
	Mass -> {MH, 125},
        Width -> {WH, 0.00679485838},
	PropagatorLabel -> "H",
	PropagatorType -> D,
	PropagatorArrow -> None,
        PDG -> 25,
        TeXParticleName -> "\\phi",
        TeXClassName -> "\\phi",
        FullName -> "H" },

S[2] == {
        ClassName -> phi,
	SelfConjugate -> True,
	Mass -> {MZ, 91.5445065},
        Width -> Wphi,
	PropagatorLabel -> "Phi",
	PropagatorType -> D,
	PropagatorArrow -> None,
	ParticleName ->"phi0",
        PDG -> 250,
        FullName -> "Phi",
        Goldstone -> Z },

S[3] == {
        ClassName -> phi2,
	SelfConjugate -> False,
	Mass -> {MW, Internal},
        Width -> Wphi2,
	PropagatorLabel -> "Phi2",
	PropagatorType -> D,
	PropagatorArrow -> None,
	ParticleName ->"phi+",
	AntiParticleName ->"phi-",
        PDG -> 251,
        FullName -> "Phi2",
        TeXClassName -> "\\phi^+",
        TeXParticleName -> "\\phi^+",
        TeXAntiParticleName -> "\\phi^-",
        Goldstone -> W,
        QuantumNumbers -> {Q -> 1}}
}


(*****************************************************************************************)

(* SM Lagrangian *)

(******************** Gauge F^2 Lagrangian terms*************************)
(*Sign convention from Lagrangian in between Eq. (A.9) and Eq. (A.10) of Peskin & Schroeder.*)
 LGauge = -1/4 (del[Wi[nu, i1], mu] - del[Wi[mu, i1], nu] + gw Eps[i1, i2, i3] Wi[mu, i2] Wi[nu, i3])*
 					(del[Wi[nu, i1], mu] - del[Wi[mu, i1], nu] + gw Eps[i1, i4, i5] Wi[mu, i4] Wi[nu, i5]) -
	
	1/4 (del[B[nu], mu] - del[B[mu], nu])^2 -
	
	1/4 (del[G[nu, a1], mu] - del[G[mu, a1], nu] + gs f[a1, a2, a3] G[mu, a2] G[nu, a3])*
 		 (del[G[nu, a1], mu] - del[G[mu, a1], nu] + gs f[a1, a4, a5] G[mu, a4] G[nu, a5]);


(********************* Fermion Lagrangian terms*************************)
(*Sign convention from Lagrangian in between Eq. (A.9) and Eq. (A.10) of Peskin & Schroeder.*)
 LFermions = Module[{Lkin, LQCD, LEWleft, LEWright},

    Lkin = I uqbar.Ga[mu].del[uq, mu] + 
    	I dqbar.Ga[mu].del[dq, mu] + 
    	I lbar.Ga[mu].del[l, mu] + 
    	I vlbar.Ga[mu].del[vl, mu];

    LQCD = gs (uqbar.Ga[mu].T[a].uq + 
    	dqbar.Ga[mu].T[a].dq)G[mu, a];

    LBright = 
       -2ee/cw B[mu]/2 lbar.Ga[mu].ProjP.l +           (*Y_lR=-2*)
    	4ee/3/cw B[mu]/2 uqbar.Ga[mu].ProjP.uq -       (*Y_uR=4/3*)
    	2ee/3/cw B[mu]/2 dqbar.Ga[mu].ProjP.dq;        (*Y_dR=-2/3*)

    LBleft = 
       -ee/cw B[mu]/2 vlbar.Ga[mu].ProjM.vl -          (*Y_LL=-1*)
    	ee/cw B[mu]/2 lbar.Ga[mu].ProjM.l  +           (*Y_LL=-1*)
    	ee/3/cw B[mu]/2 uqbar.Ga[mu].ProjM.uq +        (*Y_QL=1/3*)
    	ee/3/cw B[mu]/2 dqbar.Ga[mu].ProjM.dq ;        (*Y_QL=1/3*)
	
    LWleft = ee/sw/2(
	vlbar.Ga[mu].ProjM.vl Wi[mu, 3] -              (*sigma3 = ( 1   0 )*)
    	lbar.Ga[mu].ProjM.l Wi[mu, 3] +                (*         ( 0  -1 )*)
    	
    	Sqrt[2] vlbar.Ga[mu].ProjM.l W[mu] +
    	Sqrt[2] lbar.Ga[mu].ProjM.vl Wbar[mu]+
    	
    	uqbar.Ga[mu].ProjM.uq Wi[mu, 3] -              (*sigma3 = ( 1   0 )*)
    	dqbar.Ga[mu].ProjM.dq Wi[mu, 3] +              (*         ( 0  -1 )*)
    	
    	Sqrt[2] uqbar.Ga[mu].ProjM.CKM.dq W[mu] +
    	Sqrt[2] dqbar.Ga[mu].ProjM.HC[CKM].uq Wbar[mu]
    	);

    Lkin + LQCD + LBright + LBleft + LWleft];


(** Note : Modifications to the SM W and Z currents should be considered here above **)

(******************** Higgs Lagrangian terms****************************)
 Phi := If[FeynmanGauge, {-I phi2, (v + H + I phi)/Sqrt[2]}, {0, (v + H)/Sqrt[2]}];
 Phibar := If[FeynmanGauge, {I phi2bar, (v + H - I phi)/Sqrt[2]} ,{0, (v + H)/Sqrt[2]}];
 

    
 LHiggs := Block[{PMVec, WVec, Dc, Dcbar, Vphi},
    
    PMVec = Table[PauliSigma[i], {i, 3}];   
    Wvec[mu_] := {Wi[mu, 1], Wi[mu, 2], Wi[mu, 3]};

	(*Y_phi=1*)
    Dc[f_, mu_] := I del[f, mu] + ee/cw B[mu]/2 f + ee/sw/2 (Wvec[mu].PMVec).f;
    Dcbar[f_, mu_] := -I del[f, mu] + ee/cw B[mu]/2 f + ee/sw/2 f.(Wvec[mu].PMVec);
    Vphi[Phi_, Phibar_] := -muH^2 Phibar.Phi + \[Lambda] (Phibar.Phi)^2;

    (Dcbar[Phibar, mu]).Dc[Phi, mu] - Vphi[Phi, Phibar]];
    

(*************** Yukawa Lagrangian***********************)
LYuk := If[FeynmanGauge,

      Module[{s,r,n,m,i},                                              	                  -
	      yd[m] CKM[n,m]     uqbar[s,n,i].ProjP[s,r].dq[r,m,i] (-I phi2)              -
	      yd[n]              dqbar[s,n,i].ProjP[s,r].dq[r,n,i] (v+H +I phi)/Sqrt[2]   -
	 
	      yu[n]              uqbar[s,n,i].ProjP[s,r].uq[r,n,i] (v+H -I phi)/Sqrt[2]   + (*This sign from eps matrix*)	
	      yu[m] Conjugate[CKM[m,n]] dqbar[s,n,i].ProjP[s,r].uq[r,m,i] ( I phi2bar)    -
	
	      yl[n]              vlbar[s,n].ProjP[s,r].l[r,n]      (-I phi2)              -
	      yl[n]               lbar[s,n].ProjP[s,r].l[r,n]      (v+H +I phi)/Sqrt[2]
           ],
           
	   Module[{s,r,n,m,i},                                                    -
	      yd[n]              dqbar[s,n,i].ProjP[s,r].dq[r,n,i] (v+H)/Sqrt[2]  -
	      yu[n]              uqbar[s,n,i].ProjP[s,r].uq[r,n,i] (v+H)/Sqrt[2]  -
	      yl[n]               lbar[s,n].ProjP[s,r].l[r,n]      (v+H)/Sqrt[2]
           ]
         ];

LYukawa := LYuk + HC[LYuk];

(** Note : Modifications to the SM H currents should be considered here above **)

(**************Ghost terms**************************)
(* Now we need the ghost terms which are of the form:             *)
(* - g * antighost * d_BRST G                                     *)
(* where d_BRST G is BRST transform of the gauge fixing function. *)

LGhost := If[FeynmanGauge, 
		Block[{dBRSTG,LGhostG,dBRSTWi,LGhostWi,dBRSTB,LGhostB},
		
	(***********First the pure gauge piece.**********************) 	
	dBRSTG[mu_,a_] := 1/gs Module[{a2, a3}, del[ghG[a], mu] + gs f[a,a2,a3] G[mu,a2] ghG[a3]];
		LGhostG := - gs ghGbar[a].del[dBRSTG[mu,a],mu];
 	
	dBRSTWi[mu_,i_] := sw/ee Module[{i2, i3}, del[ghWi[i], mu] + ee/sw Eps[i,i2,i3] Wi[mu,i2] ghWi[i3] ];
		LGhostWi := - ee/sw ghWibar[a].del[dBRSTWi[mu,a],mu];	
 	
	dBRSTB[mu_] := cw/ee del[ghB, mu];
		LGhostB := - ee/cw ghBbar.del[dBRSTB[mu],mu];
	
	(***********Next the piece from the scalar field.************)
	LGhostphi := -   ee/(2*sw*cw) MW ( - I phi2    ( (cw^2-sw^2)ghWpbar.ghZ + 2sw*cw ghWpbar.ghA )  +
			I phi2bar ( (cw^2-sw^2)ghWmbar.ghZ + 2sw*cw ghWmbar.ghA )    ) -
			ee/(2*sw) MW ( ( (v+H) + I phi) ghWpbar.ghWp + ( (v+H) - I phi) ghWmbar.ghWm   ) -
			I ee/(2*sw) MZ ( - phi2bar ghZbar.ghWp + phi2 ghZbar.ghWm ) -
			ee/(2*sw*cw) MZ (v+H) ghZbar.ghZ ;
		 	
		 	
	(***********Now add the pieces together.********************)
	LGhostG + LGhostWi + LGhostB + LGhostphi]

, 

        (*If unitary gauge, only include the gluonic ghost.*)
                Block[{dBRSTG,LGhostG},
		
	(***********First the pure gauge piece.**********************) 	
	dBRSTG[mu_,a_] := 1/gs Module[{a2, a3}, del[ghG[a], mu] + gs f[a,a2,a3] G[mu,a2] ghG[a3]];
		LGhostG := - gs ghGbar[a].del[dBRSTG[mu,a],mu];		 	
		 	
	(***********Now add the pieces together.********************)
	LGhostG]

];
		
(*********SM Lagrangian*******)	 	
LSM := LGauge + LHiggs + LFermions + LYukawa  + LGhost;


(*********VLQ Lagrangians*******)
(** We assume that the physical and mass eigenstates match for vector-like quarks **)
	 	
(*********LB, EW interactions*******)

LBW :=
+KB*KBdLw*(bpbar.Wbar[mu].Ga[mu].ProjM.u)+KB*KBdRw*(bpbar.Wbar[mu].Ga[mu].ProjP.u)+KB*KBdLw*(ubar.W[mu].Ga[mu].ProjM.bp)+KB*KBdRw*(ubar.W[mu].Ga[mu].ProjP.bp)+KB*KBsLw*(bpbar.Wbar[mu].Ga[mu].ProjM.c)+KB*KBsRw*(bpbar.Wbar[mu].Ga[mu].ProjP.c)+KB*KBsLw*(cbar.W[mu].Ga[mu].ProjM.bp)+KB*KBsRw*(cbar.W[mu].Ga[mu].ProjP.bp)+KB*KBbLw*(bpbar.Wbar[mu].Ga[mu].ProjM.t)+KB*KBbRw*(bpbar.Wbar[mu].Ga[mu].ProjP.t)+KB*KBbLw*(tbar.W[mu].Ga[mu].ProjM.bp)+KB*KBbRw*(tbar.W[mu].Ga[mu].ProjP.bp);

LBZ :=+KB*KBdLz*(bpbar.Z[mu].Ga[mu].ProjM.d)+KB*KBdRz*(bpbar.Z[mu].Ga[mu].ProjP.d)+KB*KBdLz*(dbar.Z[mu].Ga[mu].ProjM.bp)+KB*KBdRz*(dbar.Z[mu].Ga[mu].ProjP.bp)+KB*KBsLz*(bpbar.Z[mu].Ga[mu].ProjM.s)+KB*KBsRz*(bpbar.Z[mu].Ga[mu].ProjP.s)+KB*KBsLz*(sbar.Z[mu].Ga[mu].ProjM.bp)+KB*KBsRz*(sbar.Z[mu].Ga[mu].ProjP.bp)+KB*KBbLz*(bpbar.Z[mu].Ga[mu].ProjM.b)+KB*KBbRz*(bpbar.Z[mu].Ga[mu].ProjP.b)+KB*KBbLz*(bbar.Z[mu].Ga[mu].ProjM.bp)+KB*KBbRz*(bbar.Z[mu].Ga[mu].ProjP.bp);

LBH:=-KB*MQ*KBdLh*(bpbar.H.ProjP.d)/v-KB*MQ*KBdLh*(dbar.H.ProjM.bp)/v-KB*MQ*KBdRh*(bpbar.H.ProjM.d)/v-KB*MQ*KBdRh*(dbar.H.ProjP.bp)/v-KB*MQ*KBsLh*(bpbar.H.ProjP.s)/v-KB*MQ*KBsLh*(sbar.H.ProjM.bp)/v-KB*MQ*KBsRh*(bpbar.H.ProjM.s)/v-KB*MQ*KBsRh*(sbar.H.ProjP.bp)/v-KB*MQ*KBbLh*(bpbar.H.ProjP.b)/v-KB*MQ*KBbLh*(bbar.H.ProjM.bp)/v-KB*MQ*KBbRh*(bpbar.H.ProjM.b)/v-KB*MQ*KBbRh*(bbar.H.ProjP.bp)/v;



(*********B-gauge interaction*******)

    LBVL = -Gvl*ee/cw/3/2 B[mu]/2 bpbar.Ga[mu].bp;        (*Y_QL=1/3*)
	
    LWVL = -Gvl*ee/sw/2/2 (bpbar.Ga[mu].bp Wi[mu,3]);


(*********Kinetic, mass & QCD lagrangians for VLQ*******)

LBK := I bpbar.Ga[mu].del[bp, mu];

LBM := -MQ.bpbar.bp;

LBG :=  gs (bpbar.Ga[mu].T[a].bp)G[mu, a];

LB := LBW + LBZ + LBH + LBK + LBM + LBG;

LVLQ := LB + LBVL + LWVL;



(*********Total Lagrangian*******)

L := LSM + LVLQ;


